@@ -15,6 +15,15 @@ class TakemeClient:
 
         return response.json()
 
+    def non_auth_call_with_pin(self, body, endpoint, pin):
+        encrypted_pin = RsaUtil.encrypt(pin)
+        response = self.request_takeme.call_api_without_bearer_and_pin(endpoint, body, encrypted_pin)
+
+        if response.status_code != 200:
+            raise ValueError(response.json())
+
+        return response.json()
+
     def auth_call(self, body, endpoint, jwt):
         response = self.request_takeme.call_api_with_bearer(endpoint, body, jwt)
 
@@ -176,7 +185,7 @@ class TakemeClient:
 
         return response.get("data")
 
-    def corporate_inquiry_bank_account(self, account_number, bank_code,):
+    def corporate_inquiry_bank_account(self, account_number, bank_code):
         endpoint = "corporate/account-holdername"
         body = {
             "account_number": account_number,
@@ -185,4 +194,55 @@ class TakemeClient:
 
         response = self.non_auth_call(body, endpoint)
 
-        return response.get("data")
\ No newline at end of file
+        return response.get("data")
+
+    def corporate_save_pin(self, pin):
+        endpoint = "corporate/save-pin"
+        body = {
+            "pin": RsaUtil.encrypt(pin)
+        }
+
+        self.non_auth_call(body, endpoint)
+
+    def corporate_pre_forgot_pin(self, new_pin):
+        endpoint = "corporate/pre-forgot-pin"
+        body = {
+            "pin": RsaUtil.encrypt(new_pin)
+        }
+
+        self.non_auth_call(body, endpoint)
+
+    def corporate_confirm_forgot_pin(self, otp):
+        endpoint = "corporate/forgot-pin"
+        body = {
+            "confirm_pin_code": otp
+        }
+
+        self.non_auth_call(body, endpoint)
+
+    def corporate_change_pin(self, old_pin, new_pin):
+        endpoint = "user/change-pin"
+        body = {
+            "old_pin": RsaUtil.encrypt(old_pin),
+            "new_pin": RsaUtil.encrypt(new_pin)
+        }
+
+        self.non_auth_call(body, endpoint)
+
+    def corporate_topup_user(self, phone_number, amount):
+        endpoint = "user/topup-user"
+        body = {
+            "phone_number": phone_number,
+            "amount": amount
+        }
+
+        self.non_auth_call(body, endpoint)
+
+    def corporate_deduct_user(self, phone_number, amount, pin):
+        endpoint = "user/deduct-user"
+        body = {
+            "phone_number": phone_number,
+            "amount": amount
+        }
+
+        self.non_auth_call_with_pin(body, endpoint, pin)
\ No newline at end of file
